% This file is part of vntex. License: GPL.
%
% This is the file t5enc.def which provides T5 encoding for Vietnamese.
%
% written by Werner Lemberg <wl@gnu.org> and
%            Vladimir Volovich <vvv@vvv.vsu.ru>

\ProvidesFile{t5enc.def}[2000/01/27 v1.0 Vietnamese T5 encoding]

\DeclareFontEncoding{T5}{}{}

\DeclareTextAccent{\`}{T5}{0}
\DeclareTextAccent{\'}{T5}{1}
\DeclareTextAccent{\^}{T5}{2}
\DeclareTextAccent{\~}{T5}{3}
\DeclareTextAccent{\"}{T5}{4}
\DeclareTextAccent{\d}{T5}{5}
\DeclareTextAccent{\r}{T5}{6}
\DeclareTextAccent{\v}{T5}{7}
\DeclareTextAccent{\u}{T5}{8}
\DeclareTextAccent{\=}{T5}{9}
\DeclareTextAccent{\.}{T5}{10}

\DeclareTextCommand{\b}{T5}[1]
  {{\o@lign{\relax#1\crcr\hidewidth\sh@ft{29}%
    \vbox to.2ex{\hbox{\char9}\vss}\hidewidth}}}

\DeclareTextCommand{\c}{T5}[1]
  {\leavevmode\setbox\z@\hbox{#1}\ifdim\ht\z@=1ex\accent11 #1%
    \else{\ooalign{\hidewidth\char11\hidewidth
      \crcr\unhbox\z@}}\fi}

% Vietnamese hook accent
\DeclareTextAccent{\h}{T5}{12}

\DeclareTextSymbol{\quotesinglbase}{T5}{13}
\DeclareTextSymbol{\guilsinglleft}{T5}{14}
\DeclareTextSymbol{\guilsinglright}{T5}{15}
\DeclareTextSymbol{\textquotedblleft}{T5}{16}
\DeclareTextSymbol{\textquotedblright}{T5}{17}
\DeclareTextSymbol{\quotedblbase}{T5}{18}
\DeclareTextSymbol{\guillemotleft}{T5}{19}
\DeclareTextSymbol{\guillemotright}{T5}{20}
\DeclareTextSymbol{\textendash}{T5}{21}
\DeclareTextSymbol{\textemdash}{T5}{22}
\DeclareTextSymbol{\textcompwordmark}{T5}{23}

\DeclareTextCommand{\textperthousand}{T5}{\%\char 24 }
\DeclareTextCommand{\textpertenthousand}{T5}{\%\char 24\char 24 }
\DeclareTextSymbol{\i}{T5}{25}

\DeclareTextSymbol{\textvisiblespace}{T5}{32}
\DeclareTextSymbol{\textquotedbl}{T5}{`\"}
\DeclareTextSymbol{\textdollar}{T5}{`\$}
\DeclareTextSymbol{\textquoteright}{T5}{`\'}
\DeclareTextSymbol{\textless}{T5}{`\<}
\DeclareTextSymbol{\textgreater}{T5}{`\>}
\DeclareTextSymbol{\textbackslash}{T5}{`\\}
\DeclareTextSymbol{\textasciicircum}{T5}{`\^}
\DeclareTextSymbol{\textunderscore}{T5}{95}
\DeclareTextSymbol{\textquoteleft}{T5}{`\`}
\DeclareTextSymbol{\textbraceleft}{T5}{`\{}
\DeclareTextSymbol{\textbar}{T5}{`\|}
\DeclareTextSymbol{\textbraceright}{T5}{`\}}
\DeclareTextSymbol{\textasciitilde}{T5}{`\~}

% A fake accent for the horn.
\DeclareTextCommand{\horn}{T5}[1]{\TextSymbolUnavailable{\horn{#1}}#1}

\DeclareTextComposite{\`}{T5}{A}{128}
\DeclareTextComposite{\'}{T5}{A}{129}
\DeclareTextComposite{\~}{T5}{A}{130}
\DeclareTextComposite{\h}{T5}{A}{131}
\DeclareTextComposite{\d}{T5}{A}{132}

\DeclareTextComposite{\^}{T5}{A}{133}
\DeclareTextDoubleComposite{\`}{T5}{\^}{A}{134}
\DeclareTextDoubleComposite{\'}{T5}{\^}{A}{135}
\DeclareTextDoubleComposite{\~}{T5}{\^}{A}{136}
\DeclareTextDoubleComposite{\h}{T5}{\^}{A}{137}
\DeclareTextDoubleComposite{\d}{T5}{\^}{A}{138}

\DeclareTextComposite{\u}{T5}{A}{139}
\DeclareTextDoubleComposite{\`}{T5}{\u}{A}{140}
\DeclareTextDoubleComposite{\'}{T5}{\u}{A}{141}
\DeclareTextDoubleComposite{\~}{T5}{\u}{A}{142}
\DeclareTextDoubleComposite{\h}{T5}{\u}{A}{143}
\DeclareTextDoubleComposite{\d}{T5}{\u}{A}{144}

\DeclareTextComposite{\`}{T5}{E}{145}
\DeclareTextComposite{\'}{T5}{E}{146}
\DeclareTextComposite{\~}{T5}{E}{147}
\DeclareTextComposite{\h}{T5}{E}{148}
\DeclareTextComposite{\d}{T5}{E}{149}

\DeclareTextComposite{\^}{T5}{E}{150}
\DeclareTextDoubleComposite{\`}{T5}{\^}{E}{151}
\DeclareTextDoubleComposite{\'}{T5}{\^}{E}{152}
\DeclareTextDoubleComposite{\~}{T5}{\^}{E}{153}
\DeclareTextDoubleComposite{\h}{T5}{\^}{E}{154}
\DeclareTextDoubleComposite{\d}{T5}{\^}{E}{155}

\DeclareTextComposite{\`}{T5}{I}{156}
\DeclareTextComposite{\'}{T5}{I}{157}
\DeclareTextComposite{\~}{T5}{I}{158}
\DeclareTextComposite{\h}{T5}{I}{159}
\DeclareTextComposite{\d}{T5}{I}{192}

\DeclareTextComposite{\`}{T5}{O}{193}
\DeclareTextComposite{\'}{T5}{O}{194}
\DeclareTextComposite{\~}{T5}{O}{195}
\DeclareTextComposite{\h}{T5}{O}{196}
\DeclareTextComposite{\d}{T5}{O}{197}

\DeclareTextComposite{\^}{T5}{O}{198}
\DeclareTextDoubleComposite{\`}{T5}{\^}{O}{199}
\DeclareTextDoubleComposite{\'}{T5}{\^}{O}{200}
\DeclareTextDoubleComposite{\~}{T5}{\^}{O}{201}
\DeclareTextDoubleComposite{\h}{T5}{\^}{O}{202}
\DeclareTextDoubleComposite{\d}{T5}{\^}{O}{203}

\DeclareTextComposite{\horn}{T5}{O}{204}
\DeclareTextDoubleComposite{\`}{T5}{\horn}{O}{205}
\DeclareTextDoubleComposite{\'}{T5}{\horn}{O}{206}
\DeclareTextDoubleComposite{\~}{T5}{\horn}{O}{207}
\DeclareTextDoubleComposite{\h}{T5}{\horn}{O}{208}
\DeclareTextDoubleComposite{\d}{T5}{\horn}{O}{209}

\DeclareTextComposite{\`}{T5}{U}{210}
\DeclareTextComposite{\'}{T5}{U}{211}
\DeclareTextComposite{\~}{T5}{U}{212}
\DeclareTextComposite{\h}{T5}{U}{213}
\DeclareTextComposite{\d}{T5}{U}{214}

\DeclareTextComposite{\horn}{T5}{U}{215}
\DeclareTextDoubleComposite{\`}{T5}{\horn}{U}{216}
\DeclareTextDoubleComposite{\'}{T5}{\horn}{U}{217}
\DeclareTextDoubleComposite{\~}{T5}{\horn}{U}{218}
\DeclareTextDoubleComposite{\h}{T5}{\horn}{U}{219}
\DeclareTextDoubleComposite{\d}{T5}{\horn}{U}{220}

\DeclareTextComposite{\`}{T5}{Y}{221}
\DeclareTextComposite{\'}{T5}{Y}{222}
\DeclareTextComposite{\~}{T5}{Y}{223}
\DeclareTextComposite{\h}{T5}{Y}{26}
\DeclareTextComposite{\d}{T5}{Y}{28}

\DeclareTextComposite{\`}{T5}{a}{160}
\DeclareTextComposite{\'}{T5}{a}{161}
\DeclareTextComposite{\~}{T5}{a}{162}
\DeclareTextComposite{\h}{T5}{a}{163}
\DeclareTextComposite{\d}{T5}{a}{164}

\DeclareTextComposite{\^}{T5}{a}{165}
\DeclareTextDoubleComposite{\`}{T5}{\^}{a}{166}
\DeclareTextDoubleComposite{\'}{T5}{\^}{a}{167}
\DeclareTextDoubleComposite{\~}{T5}{\^}{a}{168}
\DeclareTextDoubleComposite{\h}{T5}{\^}{a}{169}
\DeclareTextDoubleComposite{\d}{T5}{\^}{a}{170}

\DeclareTextComposite{\u}{T5}{a}{171}
\DeclareTextDoubleComposite{\`}{T5}{\u}{a}{172}
\DeclareTextDoubleComposite{\'}{T5}{\u}{a}{173}
\DeclareTextDoubleComposite{\~}{T5}{\u}{a}{174}
\DeclareTextDoubleComposite{\h}{T5}{\u}{a}{175}
\DeclareTextDoubleComposite{\d}{T5}{\u}{a}{176}

\DeclareTextComposite{\`}{T5}{e}{177}
\DeclareTextComposite{\'}{T5}{e}{178}
\DeclareTextComposite{\~}{T5}{e}{179}
\DeclareTextComposite{\h}{T5}{e}{180}
\DeclareTextComposite{\d}{T5}{e}{181}

\DeclareTextComposite{\^}{T5}{e}{182}
\DeclareTextDoubleComposite{\`}{T5}{\^}{e}{183}
\DeclareTextDoubleComposite{\'}{T5}{\^}{e}{184}
\DeclareTextDoubleComposite{\~}{T5}{\^}{e}{185}
\DeclareTextDoubleComposite{\h}{T5}{\^}{e}{186}
\DeclareTextDoubleComposite{\d}{T5}{\^}{e}{187}

\DeclareTextComposite{\`}{T5}{i}{188}
\DeclareTextComposite{\'}{T5}{i}{189}
\DeclareTextComposite{\~}{T5}{i}{190}
\DeclareTextComposite{\h}{T5}{i}{191}
\DeclareTextComposite{\d}{T5}{i}{224}

\DeclareTextComposite{\`}{T5}{o}{225}
\DeclareTextComposite{\'}{T5}{o}{226}
\DeclareTextComposite{\~}{T5}{o}{227}
\DeclareTextComposite{\h}{T5}{o}{228}
\DeclareTextComposite{\d}{T5}{o}{229}

\DeclareTextComposite{\^}{T5}{o}{230}
\DeclareTextDoubleComposite{\`}{T5}{\^}{o}{231}
\DeclareTextDoubleComposite{\'}{T5}{\^}{o}{232}
\DeclareTextDoubleComposite{\~}{T5}{\^}{o}{233}
\DeclareTextDoubleComposite{\h}{T5}{\^}{o}{234}
\DeclareTextDoubleComposite{\d}{T5}{\^}{o}{235}

\DeclareTextComposite{\horn}{T5}{o}{236}
\DeclareTextDoubleComposite{\`}{T5}{\horn}{o}{237}
\DeclareTextDoubleComposite{\'}{T5}{\horn}{o}{238}
\DeclareTextDoubleComposite{\~}{T5}{\horn}{o}{239}
\DeclareTextDoubleComposite{\h}{T5}{\horn}{o}{240}
\DeclareTextDoubleComposite{\d}{T5}{\horn}{o}{241}

\DeclareTextComposite{\`}{T5}{u}{242}
\DeclareTextComposite{\'}{T5}{u}{243}
\DeclareTextComposite{\~}{T5}{u}{244}
\DeclareTextComposite{\h}{T5}{u}{245}
\DeclareTextComposite{\d}{T5}{u}{246}

\DeclareTextComposite{\horn}{T5}{u}{247}
\DeclareTextDoubleComposite{\`}{T5}{\horn}{u}{248}
\DeclareTextDoubleComposite{\'}{T5}{\horn}{u}{249}
\DeclareTextDoubleComposite{\~}{T5}{\horn}{u}{250}
\DeclareTextDoubleComposite{\h}{T5}{\horn}{u}{251}
\DeclareTextDoubleComposite{\d}{T5}{\horn}{u}{252}

\DeclareTextComposite{\`}{T5}{y}{253}
\DeclareTextComposite{\'}{T5}{y}{254}
\DeclareTextComposite{\~}{T5}{y}{255}
\DeclareTextComposite{\h}{T5}{y}{27}
\DeclareTextComposite{\d}{T5}{y}{29}

\DeclareTextSymbol{\DJ}{T5}{30}
\DeclareTextSymbol{\dj}{T5}{31}

\endinput

% end of t5enc.def
