( cd usr/doc ; rm -rf tetex-2.0.2 )
( cd usr/doc ; ln -sf /usr/share/texmf/doc tetex-2.0.2 )
( cd usr/share/texmf/bin ; rm -rf allec )
( cd usr/share/texmf/bin ; ln -sf allcm allec )
( cd usr/share/texmf/bin ; rm -rf dvilj6 )
( cd usr/share/texmf/bin ; ln -sf dvilj4 dvilj6 )
( cd usr/share/texmf/bin ; rm -rf einitex )
( cd usr/share/texmf/bin ; ln -sf etex einitex )
( cd usr/share/texmf/bin ; rm -rf elatex )
( cd usr/share/texmf/bin ; ln -sf etex elatex )
( cd usr/share/texmf/bin ; rm -rf evirtex )
( cd usr/share/texmf/bin ; ln -sf etex evirtex )
( cd usr/share/texmf/bin ; rm -rf fdf2tan )
( cd usr/share/texmf/bin ; ln -sf texexec fdf2tan )
( cd usr/share/texmf/bin ; rm -rf inimf )
( cd usr/share/texmf/bin ; ln -sf mf inimf )
( cd usr/share/texmf/bin ; rm -rf inimpost )
( cd usr/share/texmf/bin ; ln -sf mpost inimpost )
( cd usr/share/texmf/bin ; rm -rf iniomega )
( cd usr/share/texmf/bin ; ln -sf omega iniomega )
( cd usr/share/texmf/bin ; rm -rf initex )
( cd usr/share/texmf/bin ; ln -sf tex initex )
( cd usr/share/texmf/bin ; rm -rf kpsepath )
( cd usr/share/texmf/bin ; ln -sf kpsetool kpsepath )
( cd usr/share/texmf/bin ; rm -rf kpsexpand )
( cd usr/share/texmf/bin ; ln -sf kpsetool kpsexpand )
( cd usr/share/texmf/bin ; rm -rf lambda )
( cd usr/share/texmf/bin ; ln -sf omega lambda )
( cd usr/share/texmf/bin ; rm -rf latex )
( cd usr/share/texmf/bin ; ln -sf tex latex )
( cd usr/share/texmf/bin ; rm -rf makempy )
( cd usr/share/texmf/bin ; ln -sf texexec makempy )
( cd usr/share/texmf/bin ; rm -rf mf )
( cd usr/share/texmf/bin ; ln -sf mfw mf )
( cd usr/share/texmf/bin ; rm -rf mktexfmt )
( cd usr/share/texmf/bin ; ln -sf fmtutil mktexfmt )
( cd usr/share/texmf/bin ; rm -rf mptopdf )
( cd usr/share/texmf/bin ; ln -sf texexec mptopdf )
( cd usr/share/texmf/bin ; rm -rf ofm2opl )
( cd usr/share/texmf/bin ; ln -sf omfonts ofm2opl )
( cd usr/share/texmf/bin ; rm -rf opl2ofm )
( cd usr/share/texmf/bin ; ln -sf omfonts opl2ofm )
( cd usr/share/texmf/bin ; rm -rf ovf2ovp )
( cd usr/share/texmf/bin ; ln -sf omfonts ovf2ovp )
( cd usr/share/texmf/bin ; rm -rf ovp2ovf )
( cd usr/share/texmf/bin ; ln -sf omfonts ovp2ovf )
( cd usr/share/texmf/bin ; rm -rf pdfeinitex )
( cd usr/share/texmf/bin ; ln -sf pdfetex pdfeinitex )
( cd usr/share/texmf/bin ; rm -rf pdfelatex )
( cd usr/share/texmf/bin ; ln -sf pdfetex pdfelatex )
( cd usr/share/texmf/bin ; rm -rf pdfevirtex )
( cd usr/share/texmf/bin ; ln -sf pdfetex pdfevirtex )
( cd usr/share/texmf/bin ; rm -rf pdfinitex )
( cd usr/share/texmf/bin ; ln -sf pdftex pdfinitex )
( cd usr/share/texmf/bin ; rm -rf pdflatex )
( cd usr/share/texmf/bin ; ln -sf pdftex pdflatex )
( cd usr/share/texmf/bin ; rm -rf pdfvirtex )
( cd usr/share/texmf/bin ; ln -sf pdftex pdfvirtex )
( cd usr/share/texmf/bin ; rm -rf texfind )
( cd usr/share/texmf/bin ; ln -sf texexec texfind )
( cd usr/share/texmf/bin ; rm -rf texfont )
( cd usr/share/texmf/bin ; ln -sf texexec texfont )
( cd usr/share/texmf/bin ; rm -rf texhash )
( cd usr/share/texmf/bin ; ln -sf mktexlsr texhash )
( cd usr/share/texmf/bin ; rm -rf texshow )
( cd usr/share/texmf/bin ; ln -sf texexec texshow )
( cd usr/share/texmf/bin ; rm -rf texutil )
( cd usr/share/texmf/bin ; ln -sf texexec texutil )
( cd usr/share/texmf/bin ; rm -rf virmf )
( cd usr/share/texmf/bin ; ln -sf mf virmf )
( cd usr/share/texmf/bin ; rm -rf virmpost )
( cd usr/share/texmf/bin ; ln -sf mpost virmpost )
( cd usr/share/texmf/bin ; rm -rf viromega )
( cd usr/share/texmf/bin ; ln -sf omega viromega )
( cd usr/share/texmf/bin ; rm -rf virtex )
( cd usr/share/texmf/bin ; ln -sf tex virtex )
( cd usr/share/texmf/dvips/base ; rm -rf psfonts.map )
( cd usr/share/texmf/dvips/base ; ln -sf ../config/psfonts.map psfonts.map )
( cd usr/share/texmf/dvips/config ; rm -rf dvipdfm.map )
( cd usr/share/texmf/dvips/config ; ln -sf dvipdfm_ndl14.map dvipdfm.map )
( cd usr/share/texmf/dvips/config ; rm -rf pdftex.map )
( cd usr/share/texmf/dvips/config ; ln -sf pdftex_ndl14.map pdftex.map )
( cd usr/share/texmf/dvips/config ; rm -rf psfonts.map )
( cd usr/share/texmf/dvips/config ; ln -sf psfonts_t1.map psfonts.map )
( cd usr/share/texmf/man/man1 ; rm -rf MakeTeXPK.1 )
( cd usr/share/texmf/man/man1 ; ln -sf mktexpk.1 MakeTeXPK.1 )
( cd usr/share/texmf/man/man1 ; rm -rf allec.1 )
( cd usr/share/texmf/man/man1 ; ln -sf allcm.1 allec.1 )
( cd usr/share/texmf/man/man1 ; rm -rf cont-de.1 )
( cd usr/share/texmf/man/man1 ; ln -sf pdftex.1 cont-de.1 )
( cd usr/share/texmf/man/man1 ; rm -rf cont-en.1 )
( cd usr/share/texmf/man/man1 ; ln -sf pdftex.1 cont-en.1 )
( cd usr/share/texmf/man/man1 ; rm -rf cont-nl.1 )
( cd usr/share/texmf/man/man1 ; ln -sf pdftex.1 cont-nl.1 )
( cd usr/share/texmf/man/man1 ; rm -rf einitex.1 )
( cd usr/share/texmf/man/man1 ; ln -sf etex.1 einitex.1 )
( cd usr/share/texmf/man/man1 ; rm -rf elatex.1 )
( cd usr/share/texmf/man/man1 ; ln -sf etex.1 elatex.1 )
( cd usr/share/texmf/man/man1 ; rm -rf evirtex.1 )
( cd usr/share/texmf/man/man1 ; ln -sf etex.1 evirtex.1 )
( cd usr/share/texmf/man/man1 ; rm -rf inimf.1 )
( cd usr/share/texmf/man/man1 ; ln -sf mf.1 inimf.1 )
( cd usr/share/texmf/man/man1 ; rm -rf inimpost.1 )
( cd usr/share/texmf/man/man1 ; ln -sf mpost.1 inimpost.1 )
( cd usr/share/texmf/man/man1 ; rm -rf iniomega.1 )
( cd usr/share/texmf/man/man1 ; ln -sf omega.1 iniomega.1 )
( cd usr/share/texmf/man/man1 ; rm -rf initex.1 )
( cd usr/share/texmf/man/man1 ; ln -sf tex.1 initex.1 )
( cd usr/share/texmf/man/man1 ; rm -rf kpsepath.1 )
( cd usr/share/texmf/man/man1 ; ln -sf kpsetool.1 kpsepath.1 )
( cd usr/share/texmf/man/man1 ; rm -rf kpsexpand.1 )
( cd usr/share/texmf/man/man1 ; ln -sf kpsetool.1 kpsexpand.1 )
( cd usr/share/texmf/man/man1 ; rm -rf lambda.1 )
( cd usr/share/texmf/man/man1 ; ln -sf omega.1 lambda.1 )
( cd usr/share/texmf/man/man1 ; rm -rf pdfinitex.1 )
( cd usr/share/texmf/man/man1 ; ln -sf pdftex.1 pdfinitex.1 )
( cd usr/share/texmf/man/man1 ; rm -rf pdflatex.1 )
( cd usr/share/texmf/man/man1 ; ln -sf pdftex.1 pdflatex.1 )
( cd usr/share/texmf/man/man1 ; rm -rf pdfvirtex.1 )
( cd usr/share/texmf/man/man1 ; ln -sf pdftex.1 pdfvirtex.1 )
( cd usr/share/texmf/man/man1 ; rm -rf texhash.1 )
( cd usr/share/texmf/man/man1 ; ln -sf mktexlsr.1 texhash.1 )
( cd usr/share/texmf/man/man1 ; rm -rf virmf.1 )
( cd usr/share/texmf/man/man1 ; ln -sf mf.1 virmf.1 )
( cd usr/share/texmf/man/man1 ; rm -rf virmpost.1 )
( cd usr/share/texmf/man/man1 ; ln -sf mpost.1 virmpost.1 )
( cd usr/share/texmf/man/man1 ; rm -rf viromega.1 )
( cd usr/share/texmf/man/man1 ; ln -sf omega.1 viromega.1 )
( cd usr/share/texmf/man/man1 ; rm -rf virtex.1 )
( cd usr/share/texmf/man/man1 ; ln -sf tex.1 virtex.1 )
( cd usr/share/texmf/web2c ; rm -rf mf-nowin.base )
( cd usr/share/texmf/web2c ; ln -sf mf.base mf-nowin.base )
( cd usr/share/texmf/web2c ; rm -rf mfw.base )
( cd usr/share/texmf/web2c ; ln -sf mf.base mfw.base )
( cd usr/share/texmf/web2c ; rm -rf plain.base )
( cd usr/share/texmf/web2c ; ln -sf mf.base plain.base )
( cd usr/share/texmf/web2c ; rm -rf plain.fmt )
( cd usr/share/texmf/web2c ; ln -sf tex.fmt plain.fmt )
( cd usr/share/texmf/web2c ; rm -rf plain.mem )
( cd usr/share/texmf/web2c ; ln -sf mpost.mem plain.mem )
