%%
%% This is file `lgrenc.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% greek.fdd  (with options: `LGRenc')
%% This is a generated file.
%% 
%% Copyright 2001 Johannes L. Braams and any individual authors
%% listed elsewhere in this file.  All rights reserved.
%% 
%% This file is part of the Babel system, release 3.7.
%% ---------------------------------------------------
%% 
%% It may be distributed under the terms of the LaTeX Project Public
%% License, as described in lppl.txt in the base LaTeX distribution.
%% Either version 1.2 or, at your option, any later version.
%% 
%% In particular, permission is granted to customize the declarations in
%% this file to serve the needs of your installation.
%% 
%% However, NO PERMISSION is granted to distribute a modified version
%% of this file under its original name.
%% 
\ProvidesFile{lgrenc.def}
         [2001/01/30 v2.2e %
  Greek Encoding]
\DeclareFontEncoding{LGR}{}{}
\DeclareFontSubstitution{LGR}{cmr}{m}{n}
\DeclareErrorFont{LGR}{cmr}{m}{n}{10}
\ProvideTextCommand{\textcopyright}{LGR}{%
  \textcircled{\textlatin{c}}}
\ProvideTextCommand{\textregistered}{LGR}{%
  \textcircled{\textlatin{\textsc r}}}
\ProvideTextCommand{\texttrademark}{LGR}{%
  \textsuperscript{\textlatin{TM}}}
\ProvideTextCommand{\SS}{LGR}{%
  \textlatin{SS}}
\endinput
%%
%% End of file `lgrenc.def'.
