%%
%% This is file `maccyr.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% cyinpenc.dtx  (with options: `maccyrillic')
%% This file is a generated file from the sources of the `cyrillic' bundle
%% in the LaTeX2e distribution.
%% 
%% This is a generated file.
%% 
%% Copyright 1998 1999 2000 2001
%% The LaTeX3 Project and any individual authors listed elsewhere
%% in this file.
%% 
%% This file was generated from file(s) of the Standard LaTeX `Cyrillic Bundle'.
%% -----------------------------------------------------------------------------
%% 
%% It may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.2
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%    http://www.latex-project.org/lppl.txt
%% and version 1.2 or later is part of all distributions of LaTeX
%% version 1999/12/01 or later.
%% 
%% This file may only be distributed together with a copy of the LaTeX
%% `Cyrillic Bundle'. You may however distribute the LaTeX `Cyrillic
%% Bundle' without such generated files.
%% 
%% The list of all files belonging to the `Cyrillic Bundle' is
%% given in the file `manifest.txt'.
%% 
\ProvidesFile{maccyr.def}
  [1999/11/16 v1.0d Input encoding file]
\makeatletter
\ProvideTextCommandDefault{\textdegree}{\ensuremath{{^\circ}}}
\DeclareInputText{128}{\CYRA}
\DeclareInputText{129}{\CYRB}
\DeclareInputText{130}{\CYRV}
\DeclareInputText{131}{\CYRG}
\DeclareInputText{132}{\CYRD}
\DeclareInputText{133}{\CYRE}
\DeclareInputText{134}{\CYRZH}
\DeclareInputText{135}{\CYRZ}
\DeclareInputText{136}{\CYRI}
\DeclareInputText{137}{\CYRISHRT}
\DeclareInputText{138}{\CYRK}
\DeclareInputText{139}{\CYRL}
\DeclareInputText{140}{\CYRM}
\DeclareInputText{141}{\CYRN}
\DeclareInputText{142}{\CYRO}
\DeclareInputText{143}{\CYRP}
\DeclareInputText{144}{\CYRR}
\DeclareInputText{145}{\CYRS}
\DeclareInputText{146}{\CYRT}
\DeclareInputText{147}{\CYRU}
\DeclareInputText{148}{\CYRF}
\DeclareInputText{149}{\CYRH}
\DeclareInputText{150}{\CYRC}
\DeclareInputText{151}{\CYRCH}
\DeclareInputText{152}{\CYRSH}
\DeclareInputText{153}{\CYRSHCH}
\DeclareInputText{154}{\CYRHRDSN}
\DeclareInputText{155}{\CYRERY}
\DeclareInputText{156}{\CYRSFTSN}
\DeclareInputText{157}{\CYREREV}
\DeclareInputText{158}{\CYRYU}
\DeclareInputText{159}{\CYRYA}
\DeclareInputText{160}{\dag}
\DeclareInputText{161}{\textdegree}
\DeclareInputText{162}{\textcent}
\DeclareInputText{163}{\pounds}
\DeclareInputText{164}{\S}
\DeclareInputText{165}{\textbullet}
\DeclareInputText{166}{\P}
\DeclareInputText{167}{\CYRII}
\DeclareInputText{168}{\textregistered}
\DeclareInputText{169}{\copyright}
\DeclareInputText{170}{\texttrademark}
\DeclareInputText{171}{\CYRDJE}
\DeclareInputText{172}{\cyrdje}
\DeclareInputMath{173}{\neq}
\DeclareInputText{174}{\@tabacckludge'\CYRG}
\DeclareInputText{175}{\@tabacckludge'\cyrg}
\DeclareInputMath{176}{\infty}
\DeclareInputMath{177}{\pm}
\DeclareInputMath{178}{\leq}
\DeclareInputMath{179}{\geq}
\DeclareInputText{180}{\cyrii}
\DeclareInputMath{181}{\mu}
\DeclareInputMath{182}{\partial}
\DeclareInputText{183}{\CYRJE}
\DeclareInputText{184}{\CYRIE}
\DeclareInputText{185}{\cyrie}
\DeclareInputText{186}{\CYRYI}
\DeclareInputText{187}{\cyryi}
\DeclareInputText{188}{\CYRLJE}
\DeclareInputText{189}{\cyrlje}
\DeclareInputText{190}{\CYRNJE}
\DeclareInputText{191}{\cyrnje}
\DeclareInputText{192}{\cyrje}
\DeclareInputText{193}{\CYRDZE}
\DeclareInputMath{194}{\lnot}
\DeclareInputMath{195}{\surd}
\DeclareInputText{196}{\textflorin}
\DeclareInputMath{197}{\approx}
\DeclareInputMath{198}{\Delta}
\DeclareInputText{199}{\guillemotleft}
\DeclareInputText{200}{\guillemotright}
\DeclareInputText{201}{\dots}
\DeclareInputText{202}{\nobreakspace}
\DeclareInputText{203}{\CYRTSHE}
\DeclareInputText{204}{\cyrtshe}
\DeclareInputText{205}{\@tabacckludge'\CYRK}
\DeclareInputText{206}{\@tabacckludge'\cyrk}
\DeclareInputText{207}{\cyrdze}
\DeclareInputText{208}{\textendash}
\DeclareInputText{209}{\textemdash}
\DeclareInputText{210}{\textquotedblleft}
\DeclareInputText{211}{\textquotedblright}
\DeclareInputText{212}{\textquoteleft}
\DeclareInputText{213}{\textquoteright}
\DeclareInputMath{214}{\div}
\DeclareInputText{215}{\quotedblbase}
\DeclareInputText{216}{\CYRUSHRT}
\DeclareInputText{217}{\cyrushrt}
\DeclareInputText{218}{\CYRDZHE}
\DeclareInputText{219}{\cyrdzhe}
\DeclareInputText{220}{\textnumero}
\DeclareInputText{221}{\CYRYO}
\DeclareInputText{222}{\cyryo}
\DeclareInputText{223}{\cyrya}
\DeclareInputText{224}{\cyra}
\DeclareInputText{225}{\cyrb}
\DeclareInputText{226}{\cyrv}
\DeclareInputText{227}{\cyrg}
\DeclareInputText{228}{\cyrd}
\DeclareInputText{229}{\cyre}
\DeclareInputText{230}{\cyrzh}
\DeclareInputText{231}{\cyrz}
\DeclareInputText{232}{\cyri}
\DeclareInputText{233}{\cyrishrt}
\DeclareInputText{234}{\cyrk}
\DeclareInputText{235}{\cyrl}
\DeclareInputText{236}{\cyrm}
\DeclareInputText{237}{\cyrn}
\DeclareInputText{238}{\cyro}
\DeclareInputText{239}{\cyrp}
\DeclareInputText{240}{\cyrr}
\DeclareInputText{241}{\cyrs}
\DeclareInputText{242}{\cyrt}
\DeclareInputText{243}{\cyru}
\DeclareInputText{244}{\cyrf}
\DeclareInputText{245}{\cyrh}
\DeclareInputText{246}{\cyrc}
\DeclareInputText{247}{\cyrch}
\DeclareInputText{248}{\cyrsh}
\DeclareInputText{249}{\cyrshch}
\DeclareInputText{250}{\cyrhrdsn}
\DeclareInputText{251}{\cyrery}
\DeclareInputText{252}{\cyrsftsn}
\DeclareInputText{253}{\cyrerev}
\DeclareInputText{254}{\cyryu}
\DeclareInputText{255}{\textcurrency}
\makeatother
\endinput
%%
%% End of file `maccyr.def'.
