%%
%% This is file `lheenc.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% hebrew.fdd  (with options: `LHEenc')
%% 
%% This is a generated file.
%% 
%% Copyright 1997-1998 Boris Lavva and any individual authors
%% listed elsewhere in this file. All rights reserved.
%% 
%% This is a generated file.
%% 
%% Copyright 2001 Johannes L. Braams and any individual authors
%% listed elsewhere in this file.  All rights reserved.
%% 
%% This file is part of the Babel system, release 3.7.
%% ---------------------------------------------------
%% 
%% It may be distributed under the terms of the LaTeX Project Public
%% License, as described in lppl.txt in the base LaTeX distribution.
%% Either version 1.2 or, at your option, any later version.
%% 
%% In particular, permission is granted to customize the declarations in
%% this file to serve the needs of your installation.
%% 
%% However, NO PERMISSION is granted to distribute a modified version
%% of this file under its original name.
%% 
\ProvidesFile{lheenc.def}
        [2001/02/16 v1.0c
         7-bit Hebrew font encoding
         (test version: still liable to change)]
\DeclareFontEncoding{LHE}{}{}
\DeclareFontSubstitution{LHE}{cmr}{m}{n}
\DeclareErrorFont{LHE}{cmr}{m}{n}{10}
\ProvideTextCommand{\textcopyright}{LHE}{\textcircled{\@latin{c}}}
\ProvideTextCommand{\textregistered}{LHE}{\textcircled{\scshape%
                                          \@latin{r}}}
\ProvideTextCommand{\texttrademark}{LHE}{\textsuperscript{\@latin{TM}}}
\lccode``=`` %^^A ''
\DeclareTextSymbol{\alef}{LHE}{96}
\DeclareTextSymbol{\bet}{LHE}{97}
\DeclareTextSymbol{\gimel}{LHE}{98}
\DeclareTextSymbol{\dalet}{LHE}{99}
\DeclareTextSymbol{\he}{LHE}{100}
\DeclareTextSymbol{\vav}{LHE}{101}
\DeclareTextSymbol{\zayin}{LHE}{102}
\DeclareTextSymbol{\het}{LHE}{103}
\DeclareTextSymbol{\tet}{LHE}{104}
\DeclareTextSymbol{\yod}{LHE}{105}
\DeclareTextSymbol{\finalkaf}{LHE}{106}
\DeclareTextSymbol{\kaf}{LHE}{107}
\DeclareTextSymbol{\lamed}{LHE}{108}
\DeclareTextSymbol{\finalmem}{LHE}{109}
\DeclareTextSymbol{\mem}{LHE}{110}
\DeclareTextSymbol{\finalnun}{LHE}{111}
\DeclareTextSymbol{\nun}{LHE}{112}
\DeclareTextSymbol{\samekh}{LHE}{113}
\DeclareTextSymbol{\ayin}{LHE}{114}
\DeclareTextSymbol{\finalpe}{LHE}{115}
\DeclareTextSymbol{\pe}{LHE}{116}
\DeclareTextSymbol{\finaltsadi}{LHE}{117}
\DeclareTextSymbol{\tsadi}{LHE}{118}
\DeclareTextSymbol{\qof}{LHE}{119}
\DeclareTextSymbol{\resh}{LHE}{120}
\DeclareTextSymbol{\shin}{LHE}{121}
\DeclareTextSymbol{\tav}{LHE}{122}
\let\org@sin=\sin
\def\sin{\ifmmode\org@sin\else\shin\fi}
%%
%% \CharacterTable
%%  {Upper-case    \A\B\C\D\E\F\G\H\I\J\K\L\M\N\O\P\Q\R\S\T\U\V\W\X\Y\Z
%%   Lower-case    \a\b\c\d\e\f\g\h\i\j\k\l\m\n\o\p\q\r\s\t\u\v\w\x\y\z
%%   Digits        \0\1\2\3\4\5\6\7\8\9
%%   Exclamation   \!     Double quote  \"     Hash (number) \#
%%   Dollar        \$     Percent       \%     Ampersand     \&
%%   Acute accent  \'     Left paren    \(     Right paren   \)
%%   Asterisk      \*     Plus          \+     Comma         \,
%%   Minus         \-     Point         \.     Solidus       \/
%%   Colon         \:     Semicolon     \;     Less than     \<
%%   Equals        \=     Greater than  \>     Question mark \?
%%   Commercial at \@     Left bracket  \[     Backslash     \\
%%   Right bracket \]     Circumflex    \^     Underscore    \_
%%   Grave accent  \`     Left brace    \{     Vertical bar  \|
%%   Right brace   \}     Tilde         \~}
%%
\endinput
%%
%% End of file `lheenc.def'.
