% This file is part of vntex. License: GPL.
%
% This is the file tcvn.def which provides TCVN input encoding for
% Vietnamese.
%
% written by Werner Lemberg <wl@gnu.org> and
%            Han The Thanh <thanh@fi.muni.cz>

\ProvidesFile{tcvn.def}[2000/01/27 v1.0 TCVN Vietnamese input encoding]

\makeatletter

\DeclareInputText{1}{\@tabacckludge'U}
\DeclareInputText{2}{\d U}
\DeclareInputText{4}{\@tabacckludge`\horn U}
\DeclareInputText{5}{\h\horn U}
\DeclareInputText{6}{\~\horn U}
\DeclareInputText{17}{\@tabacckludge'\horn U}
\DeclareInputText{18}{\d\horn U}
\DeclareInputText{19}{\@tabacckludge`Y}
\DeclareInputText{20}{\h Y}
\DeclareInputText{21}{\~Y}
\DeclareInputText{22}{\@tabacckludge'Y}
\DeclareInputText{23}{\d Y}

\DeclareInputText{128}{\@tabacckludge`A}
\DeclareInputText{129}{\h A}
\DeclareInputText{130}{\~A}
\DeclareInputText{131}{\@tabacckludge'A}
\DeclareInputText{132}{\d A}
\DeclareInputText{133}{\d\u A}
\DeclareInputText{134}{\d\^A}
\DeclareInputText{135}{\@tabacckludge`E}
\DeclareInputText{136}{\h E}
\DeclareInputText{137}{\~E}
\DeclareInputText{138}{\@tabacckludge'E}
\DeclareInputText{139}{\d E}
\DeclareInputText{140}{\d\^E}
\DeclareInputText{141}{\@tabacckludge`I}
\DeclareInputText{142}{\h I}
\DeclareInputText{143}{\~I}

\DeclareInputText{144}{\@tabacckludge'I}
\DeclareInputText{145}{\d I}
\DeclareInputText{146}{\@tabacckludge`O}
\DeclareInputText{147}{\h O}
\DeclareInputText{148}{\~O}
\DeclareInputText{149}{\@tabacckludge'O}
\DeclareInputText{150}{\d O}
\DeclareInputText{151}{\d\^O}
\DeclareInputText{152}{\@tabacckludge`\horn O}
\DeclareInputText{153}{\h\horn O}
\DeclareInputText{154}{\~\horn O}
\DeclareInputText{155}{\@tabacckludge'\horn O}
\DeclareInputText{156}{\d\horn O}
\DeclareInputText{157}{\@tabacckludge`U}
\DeclareInputText{158}{\h U}
\DeclareInputText{159}{\~U}

\DeclareInputText{161}{\u A}
\DeclareInputText{162}{\^A}
\DeclareInputText{163}{\^E}
\DeclareInputText{164}{\^O}
\DeclareInputText{165}{\horn O}
\DeclareInputText{166}{\horn U}
\DeclareInputText{167}{\DJ}
\DeclareInputText{168}{\u a}
\DeclareInputText{169}{\^a}
\DeclareInputText{170}{\^e}
\DeclareInputText{171}{\^o}
\DeclareInputText{172}{\horn o}
\DeclareInputText{173}{\horn u}
\DeclareInputText{174}{\dj}
\DeclareInputText{175}{\@tabacckludge`\u A}

\DeclareInputText{181}{\@tabacckludge`a}
\DeclareInputText{182}{\h a}
\DeclareInputText{183}{\~a}
\DeclareInputText{184}{\@tabacckludge'a}
\DeclareInputText{185}{\d a}
\DeclareInputText{186}{\h\u A}
\DeclareInputText{187}{\@tabacckludge`\u a}
\DeclareInputText{188}{\h\u a}
\DeclareInputText{189}{\~\u a}
\DeclareInputText{190}{\@tabacckludge'\u a}
\DeclareInputText{191}{\~\u A}

\DeclareInputText{192}{\@tabacckludge'\u A}
\DeclareInputText{193}{\@tabacckludge`\^A}
\DeclareInputText{194}{\h\^A}
\DeclareInputText{195}{\~\^A}
\DeclareInputText{196}{\@tabacckludge'\^A}
\DeclareInputText{197}{\@tabacckludge`\^E}
\DeclareInputText{198}{\d\u a}
\DeclareInputText{199}{\@tabacckludge`\^a}
\DeclareInputText{200}{\h\^a}
\DeclareInputText{201}{\~\^a}
\DeclareInputText{202}{\@tabacckludge'\^a}
\DeclareInputText{203}{\d\^a}
\DeclareInputText{204}{\@tabacckludge`e}
\DeclareInputText{205}{\h\^E}
\DeclareInputText{206}{\h e}
\DeclareInputText{207}{\~e}

\DeclareInputText{208}{\@tabacckludge'e}
\DeclareInputText{209}{\d e}
\DeclareInputText{210}{\@tabacckludge`\^e}
\DeclareInputText{211}{\h\^e}
\DeclareInputText{212}{\~\^e}
\DeclareInputText{213}{\@tabacckludge'\^e}
\DeclareInputText{214}{\d\^e}
\DeclareInputText{215}{\@tabacckludge`i}
\DeclareInputText{216}{\h i}
\DeclareInputText{217}{\~\^E}
\DeclareInputText{218}{\@tabacckludge'\^E}
\DeclareInputText{219}{\@tabacckludge`\^O}
\DeclareInputText{220}{\~i}
\DeclareInputText{221}{\@tabacckludge'i}
\DeclareInputText{222}{\d i}
\DeclareInputText{223}{\@tabacckludge`o}

\DeclareInputText{224}{\h\^O}
\DeclareInputText{225}{\h o}
\DeclareInputText{226}{\~o}
\DeclareInputText{227}{\@tabacckludge'o}
\DeclareInputText{228}{\d o}
\DeclareInputText{229}{\@tabacckludge`\^o}
\DeclareInputText{230}{\h\^o}
\DeclareInputText{231}{\~\^o}
\DeclareInputText{232}{\@tabacckludge'\^o}
\DeclareInputText{233}{\d\^o}
\DeclareInputText{234}{\@tabacckludge`\horn o}
\DeclareInputText{235}{\h\horn o}
\DeclareInputText{236}{\~\horn o}
\DeclareInputText{237}{\@tabacckludge'\horn o}
\DeclareInputText{238}{\d\horn o}
\DeclareInputText{239}{\@tabacckludge`u}

\DeclareInputText{240}{\~\^O}
\DeclareInputText{241}{\h u}
\DeclareInputText{242}{\~u}
\DeclareInputText{243}{\@tabacckludge'u}
\DeclareInputText{244}{\d u}
\DeclareInputText{245}{\@tabacckludge`\horn u}
\DeclareInputText{246}{\h\horn u}
\DeclareInputText{247}{\~\horn u}
\DeclareInputText{248}{\@tabacckludge'\horn u}
\DeclareInputText{249}{\d\horn u}
\DeclareInputText{250}{\@tabacckludge`y}
\DeclareInputText{251}{\h y}
\DeclareInputText{252}{\~y}
\DeclareInputText{253}{\@tabacckludge'y}
\DeclareInputText{254}{\d y}
\DeclareInputText{255}{\@tabacckludge'\^O}

\makeatother

\endinput

% end of tcvn.def
